@@ -138,8 +138,8 @@ def parse_args():
                     'Specify without file extension.')
     parser.add_argument('--variables_scaling', type=scale, required=False, default=None,
                     help='Scale the continuous variables (‘normal’ or ‘standard’) or all variables (‘rank’ or ‘uniform’) in the dataset once all samples are generated.')
-    parser.add_argument('--scale_continuous_parents', type=to_bool, required=False, default=False,
-                    help='Scale the influence of parents on continuous variables.')
+    parser.add_argument('--scale_parents', type=to_bool, required=False, default=False,
+                    help='Scale the influence of parents on the variables.')
     args = parser.parse_args()
 
     assert args.min_discrete_value_classes <= args.max_discrete_value_classes, \
@@ -166,7 +166,7 @@ def graph_from_args(args) -> Graph:
             .with_functions(args.functions) \
             .with_conditional_gaussian(args.conditional_gaussian) \
             .with_betas(args.beta_lower_limit, args.beta_upper_limit) \
-            .with_scaled_parent_influence_on_continuous(args.scale_continuous_parents) \
+            .with_scaled_parent_influence(args.scale_parents) \
             .build()
     else:
         return GraphBuilder() \
@@ -180,7 +180,7 @@ def graph_from_args(args) -> Graph:
             .with_functions(args.functions) \
             .with_conditional_gaussian(args.conditional_gaussian) \
             .with_betas(args.beta_lower_limit, args.beta_upper_limit) \
-            .with_scaled_parent_influence_on_continuous(args.scale_continuous_parents) \
+            .with_scaled_parent_influence(args.scale_parents) \
             .build()
 
 
